PCB Environment: Data Fields

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all struct and union fields with links to the structures/unions they belong to:

### - y -

- y : dsn::Pin, dsn::Placement, dsn::Via, IPoint_2, IPoint_3, IVector_2, IVector_3, Point_25
- Y0 : IndexRange
- y0 : dsn::Connection, dsn::Segment
- Y1 : IndexRange
- y1 : dsn::Connection, dsn::Segment
- YCoord() : UniformGrid25
- YELLOW : Color
- YfIndex() : UniformGrid25
- YIndex() : UniformGrid25
- YIndexBounded() : UniformGrid25
- ymax : dsn::BBox
- ymin : dsn::BBox